@@ -43,6 +43,16 @@
  */
 #define DEFAULT_SERVER "localhost irc.efnet.net irc.undernet.org irc.dal.net"
 
+/*
+ * This is the location of your SSL certificate file.
+ * XXX - This needs to be auto-detected by configure, somehow...
+ * XXX - This is the FreeBSD location. how bogus.
+ */
+/*
+#define DEFAULT_SSL_ROOT_CERTS_LOCATION "/usr/local/share/certs/ca-root-nss.crt"
+*/
+#define DEFAULT_SSL_ROOT_CERTS_LOCATION NULL
+
 /*
  * This is an experimental feature to thwart infinite recursion.  It is not
  * very sophisticated so it's not turned on by default.  In the future I 
@@ -419,6 +429,7 @@
 #define DEFAULT_TAB 1
 #define	DEFAULT_TAB_MAX 0
 #define DEFAULT_TERM_DOES_BRIGHT_BLINK 0
+#define DEFAULT_TMUX_OPTIONS NULL
 #define DEFAULT_UNDERLINE_VIDEO 1
 #define DEFAULT_USER_INFORMATION "EPIC5 -- Into the abyss"
 #define DEFAULT_WORD_BREAK ".,; \t"
