@@ -1,4 +1,4 @@
-/* $EPIC: input.c,v 1.83 2014/04/01 18:11:14 jnelson Exp $ */
+/* $EPIC: input.c,v 1.87 2015/04/15 04:06:19 jnelson Exp $ */
 /*
  * input.c: does the actual input line stuff... keeps the appropriate stuff
  * on the input line, handles insert/delete of characters/words... the whole
@@ -250,9 +250,9 @@ BUILT_IN_KEYBINDING(debug_input_line)
 	*buffer = 0;
 	for (i = 0; i < INPUT_BUFFER_SIZE; i++)
 	{
-		sprintf(byte, "%X", INPUT_BUFFER[i]);
-		strcat(buffer, " ");
-		strcat(buffer, byte);
+		snprintf(byte, sizeof(byte), "%X", INPUT_BUFFER[i]);
+		strlcat(buffer, " ", sizeof(buffer));
+		strlcat(buffer, byte, sizeof(buffer));
 		if (INPUT_BUFFER[i] == 0)
 			break;
 	}
@@ -317,7 +317,7 @@ static int 	safe_puts (const unsigned char *str, int numcols)
 	int	allow_c1_chars = -1;
 
 	s = str;
-	while ((code_point = next_code_point(&s)))
+	while ((code_point = next_code_point(&s, 1)))
 	{
 		/* C1 chars have to be checked */
 		if (code_point >= 0x80 && code_point <= 0x9F)
@@ -385,7 +385,7 @@ static	int	recursive = 0;
  *
  * XXX For now, we ignore 'start' and always redo the whole thing.
  */
-int	retokenize_input (int start)
+static int	retokenize_input (int start)
 {
 	const unsigned char *str;
 	const unsigned char *s, *old_s;
@@ -399,7 +399,7 @@ int	retokenize_input (int start)
 
 	while (s && *s)
 	{
-		codepoint = next_code_point(&s);
+		codepoint = next_code_point(&s, 1);
 		cols = codepoint_numcolumns(codepoint);
 		/* Invalid chars are probably highlights */
 		if (cols == -1)
@@ -480,6 +480,7 @@ const char *	prompt;
 	Window 	*saved_current_window;
 	int	cols_used;
 	int	original_update;
+	Screen	*oos;
 
 	/*
 	 * No input line in dumb or bg mode.
@@ -491,6 +492,7 @@ const char *	prompt;
 	os = last_input_screen;
 	saved_current_window = current_window;
 	original_update = update;
+	oos = output_screen;
 
         for (ns = screen_list; ns; ns = ns->next)
 	{
@@ -506,6 +508,7 @@ const char *	prompt;
 
 	/* XXX The (mis)use of last_input_screen is lamentable */
 	last_input_screen = ns;
+	output_screen = ns;
 	current_window = ns->current_window;
 	update = original_update;
 	do_echo = last_input_screen->il->echo;
@@ -844,8 +847,6 @@ const char *	prompt;
 		 */
 		term_move_cursor(0, INPUT_LINE);
 
-		int	old_do_echo;
-
 		/* Forcibly output the prompt */
 		old_do_echo = term_echo(1);
 
@@ -962,6 +963,7 @@ const char *	prompt;
 	/* <<<<< END INDENT ONE TAB BACK FOR MY SANITY <<<<<< */
 	}
 
+	output_screen = oos;
         last_input_screen = os;
 	current_window = saved_current_window;
 }
