@@ -1,4 +1,4 @@
-/* $EPIC: irc.c,v 1.1450 2014/04/12 15:14:15 jnelson Exp $ */
+/* $EPIC: irc.c,v 1.1479 2015/07/11 15:11:58 jnelson Exp $ */
 /*
  * ircII: a new irc client.  I like it.  I hope you will too!
  *
@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-1.1.10";
-const char useful_info[] = "epic5 1 1 10";
+const char irc_version[] = "EPIC5-1.1.11";
+const char useful_info[] = "epic5 1 1 11";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20140413";
+const char internal_version[] = "20140711";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 1781;
+const unsigned long	commit_id = 1810;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 1781;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Desquamation";
+const char ridiculous_version_name[] = "Lucubrations";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -318,7 +318,7 @@ void	irc_exit (int really_quit, const char *format, ...)
 	flush_on_hooks();
 	flush_all_symbols();
 	window_display = old_window_display;
-	fprintf(stdout, "\r");
+	printf("\r");
 	fflush(stdout);
 
 	if (really_quit)
@@ -612,15 +612,6 @@ static	void	parse_args (int argc, char **argv)
 	if ((ptr = getenv("IRCHOST")) && *ptr)
 		tmp_hostname = ptr;
 
-	if ((ptr = getenv("IRCTRANSLATIONPATH")))
-		translation_path = malloc_strdup(ptr);
-	else
-		translation_path = malloc_strdup2(IRCLIB, "/translation/");
-
-	set_var_value(TRANSLATION_PATH_VAR, translation_path, 0);
-	new_free(&translation_path);
-	
-
 	/* The -S-option  / shebang tokeniser */
 	if (argc > 1 && ((argv[1][0] == '-' && argv[1][1] == 'S')
 		|| strchr(argv[1], ' ') != NULL 
