@@ -1,4 +1,4 @@
-/* $EPIC: numbers.c,v 1.101 2013/02/17 13:02:46 jnelson Exp $ */
+/* $EPIC: numbers.c,v 1.105 2014/03/19 14:18:46 jnelson Exp $ */
 /*
  * numbers.c: handles all those strange numeric response dished out by that
  * wacky, nutty program we call ircd 
@@ -217,6 +217,21 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 
 	current_numeric = numeric;	/* must be negative of numeric! */
 
+
+	/*
+	 * XXX-
+	 * We only have to worry about non-utf8 message anyways.
+	 * Those come into two waves:
+	 *	1. Specific words that might have come from users
+	 *	2. Anything else (that would have come from server)
+	 * Remember -- we only care about non-utf8 things.
+	 *	311	WHOISUSER	ArgList[0] (the realname)
+	 *	314	WHOWASUSER	ArgList[5] (the realname)
+	 *	322	LIST		ArgList[2] (the topic)
+	 *	332	TOPIC		ArgList[1] (the topic)
+	 *	352	WHOREPLY	ArgList[7] (the realname)
+	 */
+
 	/*
 	 * This first switch statement is only used for those numerics
 	 * which either need to perform some action before the numeric
@@ -320,7 +335,13 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 					get_server_group(from_server));
 		if ((new_servref = str_to_servref(str)) == NOSERV)
 			new_servref = str_to_newserv(str);
+
+		say("The server has asked you to switch to %s:%d.  I set up server refnum %d for you.", new_server, new_port, new_servref);
+		say("If you want to switch, do /SERVER %d", new_servref);
+
+#if 0
 		change_window_server(old_server, new_servref);
+#endif
 		from_server = old_server;
 		break;
 	}
@@ -380,6 +401,47 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		goto END;
         }
 
+	/*	311	WHOISUSER	ArgList[0] (the realname) */
+	case 311:		/* #define RPL_WHOISUSER        311 */
+	{
+		const char *nick, *user, *host, *channel, *name;
+
+		PasteArgs(ArgList, 4);
+		if (!(nick = ArgList[0]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(user = ArgList[1]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(host = ArgList[2]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(channel = ArgList[3]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(name = ArgList[4]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+
+		break;
+	}
+
+	/*	314	WHOWASUSER	ArgList[5] (the realname) */
+	case 314:		/* #define RPL_WHOWASUSER       314 */
+	{
+		const char *nick, *user, *host, *unused, *name;
+
+		PasteArgs(ArgList, 4);
+		if (!(nick = ArgList[0]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(user = ArgList[1]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(host = ArgList[2]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(unused = ArgList[3]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(name = ArgList[4]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+
+		break;
+	}
+
+
 	case 340:		/* #define RPL_USERIP?          340 */
 		if (!get_server_005(from_server, "USERIP"))
 			break;
@@ -415,6 +477,7 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		break;
 	}
 
+	/*	322	LIST		ArgList[2] (the topic)	  */
 	case 322:		/* #define RPL_LIST             322 */
 	{
 		const char *channel, *user_cnt, *line;
@@ -524,6 +587,21 @@ void 	numbered_command (const char *from, const char *comm, char const **ArgList
 		break;
 	}
 
+	/*	332	TOPIC		ArgList[1] (the topic)	  */
+	case 332:		/* #define RPL_TOPIC            332 */
+	{
+		const char *channel, *topic;
+
+		PasteArgs(ArgList, 1);
+		if (!(channel = ArgList[0]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		if (!(topic = ArgList[1]))
+			{ rfc1459_odd(from, comm, ArgList); goto END; }
+		break;
+	}
+
+
+	/*	352	WHOREPLY	ArgList[7] (the realname) */
 	case 352:		/* #define RPL_WHOREPLY         352 */
 		whoreply(from_server, NULL, comm, ArgList);
 		goto END;
