@@ -1,4 +1,4 @@
-/* $EPIC: parse.c,v 1.109 2014/04/02 17:37:08 jnelson Exp $ */
+/* $EPIC: parse.c,v 1.113 2014/12/26 15:26:45 jnelson Exp $ */
 /*
  * parse.c: handles messages from the server.   Believe it or not.  I
  * certainly wouldn't if I were you. 
@@ -326,6 +326,66 @@ static void	p_wallops (const char *from, const char *comm, const char **ArgList)
 	pop_message_from(l);
 }
 
+/*
+ * p_privmsg - Handle PRIVMSG messages from irc server
+ *
+ * Arguments:
+ *	from	- The sender of the PRIVMSG (usually a nick; servers uncommon)
+ *	comm	- The actual protocol command ("PRIVMSG")
+ *	ArgList - Arguments to the PRIVMSG:
+ *	  ArgList[0] - The receiver of the message (nick or channel)
+ *	  ArgList[1] - Payload of the message
+ *
+ * Notes:
+ *   PRIVMSGs may be sent to
+ *	1. A nick (our nick)
+ *	2. A channel (that we're on)
+ *	3. A prefix + A channel (eg "@#channel" or "+#channel")
+ *	   We treat this as #2.
+ *	4. Something else (a wall, ie, "*.iastate.edu")
+ *
+ *   PRIVMSG are sorted into several piles:
+ *	"PUBLIC" level:
+ *	1. Someone on the channel sends a message to channel	-> PUBLIC
+ *	    + The channel is current channel in any window
+ *	2. Someone on the channel sends a message to channel	-> PUBLIC_OTHER
+ *	    + The channel is NOT a current channel on any window
+ *	3. Someone not on channel sends a message to channel	-> PUBLIC_MSG
+ * 
+ *	"MSG" level:
+ *	4. A message sent to our nickname			-> MSG
+ *
+ *	"WALL" level:
+ *	5. A message sent to any other target			-> MSG_GROUP
+ *
+ *
+ *   Processing
+ *   ==========
+ *   CTCPs are delivered via PRIVMSGs, causing a rewrite of ArgList[1].
+ *	+ Most CTCPs are just removed (CTCP requests)
+ *	+ Some do in-place substitution (Encryption - ie, CTCP CAST5)
+ *	+ CTCP handling happens first, before anything below
+ *	+ CTCP handling does its own ignore, flood control, and throttling.
+ *  
+ *   If the PRIVMSG contains nothing after CTCP handling, then stop.
+ *
+ *   First, IGNOREs are checked. (CTCPs do their own ignore handling)
+ * 
+ *   If the PRIVMSG is encrypted, it will first be offered via
+ *	/ON ENCRYPTED_PRIVMSG no matter who sent it or to whom 
+ *	it was sent.
+ *
+ *   Next, flood control is checked.  
+ *
+ *   All PRIVMSGs are offered via /ON GENERAL_PRIVMSG,
+ *	no matter who sent it or to whom it was sent.  
+ *
+ *   All PRIVMSGs are offered via their respective types (see above)
+ *
+ *   Otherwise, a default message is output.
+ *
+ *   Finally, /NOTIFY is checked.
+ */
 static void	p_privmsg (const char *from, const char *comm, const char **ArgList)
 {
 	const char	*real_target, *target, *message;
@@ -1449,10 +1509,10 @@ protocol_command rfc1459[] = {
 #define NUMBER_OF_COMMANDS (sizeof(rfc1459) / sizeof(protocol_command)) - 2;
 int 	num_protocol_cmds = -1;
 
-#define islegal(c) ((((c) >= 'A') && ((c) <= '}')) || \
+#define islegal(c) ((((c) >= 'A') && ((c) <= '~')) || \
                     (((c) >= '0') && ((c) <= '9')) || \
 		     ((c) == '*') || \
-                     ((c) & 0x80))
+		     ((c) & 0x80))
 
 /*
  * parse_server: parses messages from the server, doing what should be done
@@ -1570,8 +1630,23 @@ void	rfc1459_any_to_utf8 (char *buffer, size_t buffsiz, char **extra)
 	if (x_debug & DEBUG_RECODE)
 		yell(">> Received %s", buffer);
 
+	/*
+	 * For the benefit of Fusion, I want to support ISO-2022-JP.
+	 * This encoding is "valid" UTF-8, but is not UTF-8.  So we need
+	 * to check it first.
+	 *
+	 * Please see http://www.sljfaq.org/afaq/encodings.html
+	 * There are other Japanese encodings that collide with UTF-8,
+	 * but I don't have any users to test, so I'm focused on what
+	 * I can actually test.
+	 */
+	if (is_iso2022_jp(buffer))
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell(">> This looks like a JIS message...");
+	}
 	/* If the data is already utf8, then do nothing. */
-	if ((bytes = invalid_utf8str(buffer)) == 0)
+	else if ((bytes = invalid_utf8str(buffer)) == 0)
 	{
 		return;
 	}
@@ -1613,7 +1688,7 @@ void	rfc1459_any_to_utf8 (char *buffer, size_t buffsiz, char **extra)
 	 * If the server part is not in utf8, then we need to convert it to
 	 * utf8 using the server's encoding to get nicks and channels in utf8.
 	 */
-	if (invalid_utf8str(server_part))
+	if (is_iso2022_jp(server_part) || invalid_utf8str(server_part))
 	{
 		if (x_debug & DEBUG_RECODE)
 			say(">> Need to recode server part for %d", from_server);
@@ -1636,7 +1711,9 @@ void	rfc1459_any_to_utf8 (char *buffer, size_t buffsiz, char **extra)
 	 * to figure out who sent this message, and recode it with their
 	 * encoding.  This deals with channels and nicks already in utf8.
 	 */
-	if (*payload_part && invalid_utf8str(payload_part)) do
+	if (*payload_part && 
+	     (is_iso2022_jp(payload_part) || invalid_utf8str(payload_part))) 
+	do
 	{
 		char *	server_part_copy;
 
