@@ -1,4 +1,4 @@
-/* $EPIC: recode.c,v 1.21 2014/04/11 15:12:26 jnelson Exp $ */
+/* $EPIC: recode.c,v 1.28 2015/05/16 22:36:47 jnelson Exp $ */
 /*
  * recode.c - Transcoding between string encodings
  * 
@@ -41,18 +41,21 @@
 #include <langinfo.h>
 #include <locale.h>
 #include <wctype.h>
+#ifdef HAVE_XLOCALE_H
 #include <xlocale.h>
+#endif
 
 /*
  * Here's the plan...
  *
  * * * * * PREFACE 
  *
- * There are three primary inbound sources of information:
+ * There are five primary inbound sources of information:
  *	1. Stuff you type
  *	2. Scripts you /load
  *	3. Stuff you get from IRC
- * (there are other sources, like DCC CHAT, but those aren't handled yet)
+ *	4. Stuff you get from /EXEC
+ *	5. Stuff you get from /DCC CHAT
  *
  * In an ideal world, everything would be in UTF-8, but we have to handle
  * data that is not in UTF-8 and we don't know what the encoding is. 
@@ -464,7 +467,7 @@ void	init_recodings (void)
 		recode_rules[x] = NULL;
 
 	/* XXX TODO - Sanity check the encodings first */
-	while (sanity_check_encoding(console_encoding))
+	if (sanity_check_encoding(console_encoding))
 	{
 		fprintf(stderr, "Help!  Your system doesn't have the %s encoding\n", console_encoding);
 		help_me++;
@@ -484,7 +487,7 @@ void	init_recodings (void)
 
 	if (help_me)
 	{
-		fprintf(stderr, "EPIC Version 5 - Commit Id (%d)\n", commit_id);
+		fprintf(stderr, "EPIC Version 5 - Commit Id (%lu)\n", commit_id);
 		fprintf(stderr, "Unfortunately, your iconv is missing important character encodings, and EPIC won't be able to operate properly without them.\n");
 		fprintf(stderr, "Please contact #epic on EFNet or jnelson@epicsol.org for more information.\n");
 		fprintf(stderr, "Also, check http://epicsol.org/encodings_and_locales\n");
@@ -501,7 +504,6 @@ void	init_recodings (void)
 
 	/* Rule 2 is "irc" */
 	recode_rules[2] = create_recoding_rule("irc", "ISO-8859-1", 1, ENCODING_FALLBACK);
-		reason = ENCODING_FALLBACK;
 }
 
 
@@ -608,14 +610,14 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 			continue;	/* XXX or break;? */
 
 		if (x_debug & DEBUG_RECODE)
-			yell("Evaluating rule %d: %s", i, r->target);
+			yell(">> Considering rule %d: %s", i, r->target);
 
 		/* Skip rules without targets */
 		/* BTW, this is "impossible", so a panic may be better */
 		if (r->target == NULL)
 		{
 			if (x_debug & DEBUG_RECODE)
-				yell("No target.");
+				yell("<< Rule has no target.");
 			continue;
 		}
 
@@ -628,13 +630,13 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 		if (from && !my_stricmp(r->target, "irc"))
 		{
 			if (x_debug & DEBUG_RECODE)
-				yell("irc magic rule ok for inbound msg");
+				yell("__ irc magic rule works for inbound msg");
 			goto target_ok;
 		}
 
 		/**********************************************************/
 		if (x_debug & DEBUG_RECODE)
-			yell("Server part [%s], target part [%s]", 
+			yell("-- Server part [%s], target part [%s]", 
 				r->server_part, r->target_part);
 
 		/**********************************************************/
@@ -650,12 +652,12 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 			if (!serverinfo_matches_servref(&r->si, server))
 			{
 				if (x_debug & DEBUG_RECODE)
-					yell("Server part does not match expectations for %d", server);
+					yell("<< Server part does not match expectations for %d", server);
 				continue;
 			}
 		}
 		if (x_debug & DEBUG_RECODE)
-			yell("Server part is ok");
+			yell("-- Server part is acceptable");
 
 		/*
 		 *
@@ -667,7 +669,7 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 		if (r->target_part == NULL)
 		{
 			if (x_debug & DEBUG_RECODE)
-				yell("No target part -- ok");
+				yell("__ No target part -- ok");
 			goto target_ok;
 		}
 
@@ -680,13 +682,13 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 			if (!my_stricmp(r->target_part, target))
 			{
 				if (x_debug & DEBUG_RECODE)
-					yell("Outbound message - Target matches sender -- ok");
+					yell("__ Outbound message - Target matches sender -- ok");
 				goto target_ok;
 			}
 
 			/* Not acceptable */
 			if (x_debug & DEBUG_RECODE)
-				yell("Outbound message - Target does not match sender");
+				yell("<< Outbound message - Target [%s] does not match sender [%s]", r->target_part, target);
 			continue;
 		}
 
@@ -700,25 +702,25 @@ static const char *	decide_encoding (const unsigned char *from, const unsigned c
 			if (!my_stricmp(r->target_part, target))
 			{
 				if (x_debug & DEBUG_RECODE)
-					yell("Inbound message - Target matches recipient -- ok");
+					yell("__ Inbound message - Target matches recipient -- ok");
 				goto target_ok;
 			}
 
 			if (!my_stricmp(r->target_part, from))
 			{
 				if (x_debug & DEBUG_RECODE)
-					yell("inbound message - target matches sender -- ok");
+					yell("__ inbound message - target matches sender -- ok");
 				goto target_ok;
 			}
 
 			if (x_debug & DEBUG_RECODE)
-				yell("Inbound message - not applicable");
+				yell("<< Inbound message - not applicable");
 			/* Not acceptable */
 			continue;
 		}
 
 		if (x_debug & DEBUG_RECODE)
-			yell("Other - Not acceptable");
+			yell("<< Other - Not acceptable");
 
 		/* Not acceptable */
 		continue;
@@ -758,7 +760,7 @@ target_ok:
 
 		/**********************************************************/
 		if (x_debug & DEBUG_RECODE)
-			yell("rule %d has score %d", i, this_score);
+			yell("++ Rule %d has score %d", i, this_score);
 
 		/*
 		 * 
@@ -770,8 +772,10 @@ target_ok:
 			winner = i;
 			winning_score = this_score;
 			if (x_debug & DEBUG_RECODE)
-				yell("Best rule so far");
+				yell("!! This is the best rule so far");
 		}
+		if (x_debug & DEBUG_RECODE)
+			yell("<< Done evaluating rule %d: %s", i, r->target);
 	}
 
 
@@ -780,11 +784,20 @@ target_ok:
 	 * sending an outbound message), then UTF-8 it is!
 	 */
 	if (winner == -1 && from == NULL)
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("// I decided there was no winner - UTF-8 it is");
 		return NULL;
+	}
 	if (winner == -1)
 		panic(1, "Did not find a recode rule for %d/%s/%s", 
 					server, from, target);
 
+	if (x_debug & DEBUG_RECODE)
+		yell("// The winning rule was %d, %s, %s",
+				winner,
+				recode_rules[winner]->target,
+				recode_rules[winner]->encoding);
 
 	/* If from == NULL, we are sending the message outbound */
 	if (from == NULL)
@@ -829,13 +842,28 @@ const char *	outbound_recode (const char *to, int server, const char *message, c
 
 	/* If there is no place to put the retval, don't do anything */
 	if (!extra)
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ob: extra == null, so i can't recode");
 		return message;
+	}
 
 	/* If no recoding is necessary, then we're done. */
 	if (!(encoding = decide_encoding(NULL, to, server, &i)))
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ob: I can't decide on an encoding, so i can't recode");
 		return message;
+	}
 	if (i == (iconv_t) -1)
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ob: The encoding rule didn't give me an iconv to work with.");
 		return message;
+	}
+
+	if (x_debug & DEBUG_RECODE)
+		yell("ob: Here we go, I'm recoding the ob message!");
 
 	new_buffer = malloc_strdup(message);
 	new_buffer_len = strlen(message) + 1;
@@ -889,21 +917,41 @@ const char *	inbound_recode (const char *from, int server, const char *to, const
 
 	/* The easiest thing is to accept it if it's valid UTF-8 */
 	msg = LOCAL_COPY(message);
-	if (!invalid_utf8str(msg))
+	if (!is_iso2022_jp(msg) && !invalid_utf8str(msg))
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ib: This message is valid UTF-8, so it's fine.");
 		return message;
-	
+	}
+
 	/* If there is no place to put the retval, don't do anything */
 	if (!extra)
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ib: I'd have recoded this, but extra == NULL, so I won't.");
 		return message;
+	}
 
 	/* If no recoding is necessary, then we're done. */
 	/*
 	 * XXX TODO -- This should be impossible.  A panic is probably better.
 	 */
 	if (!(encoding = decide_encoding(from, to, server, &i)))
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ib: I couldn't figure out what encoding rule to use.  This is supposed to be impossible.");
 		return message;
+	}
+
 	if (i == (iconv_t) -1)
+	{
+		if (x_debug & DEBUG_RECODE)
+			yell("ib: The encoding rule didn't seem to have an iconv handle to use. strange ");
 		return message;
+	}
+
+	if (x_debug & DEBUG_RECODE)
+		yell("ib: OK.  I'm recoding this message!");
 
 	new_buffer = malloc_strdup(message);
 	new_buffer_len = strlen(message) + 1;
@@ -931,21 +979,20 @@ int     ucs_to_console (u_32int_t codepoint, unsigned char *deststr, size_t dest
 	size_t	utf8strsiz;
 	iconv_t	xlat = (iconv_t)-1;
 	int	n;
-	char *	x;
-	const char *	s;
-	size_t	slen, xlen;
+	char *	source;
+	char *	dest;
 
 	utf8strsiz = ucs_to_utf8(codepoint, utf8str, 16) + 1;
-	find_recoding("console", NULL, &xlat);
+	source = utf8str;
 
+	find_recoding("console", NULL, &xlat);
 	/* XXX What to do is 'xlat' is (iconv_t)-1? */
 	if (xlat == (iconv_t)-1)
 		return -1;	/* What to do? */
 
-	s = utf8str;
-	x = deststr;
+	dest = deststr;
 
-	if ((n = iconv(xlat, &s, &utf8strsiz, &x, &deststrsiz)) != 0)
+	if ((n = iconv(xlat, &source, &utf8strsiz, &dest, &deststrsiz)) != 0)
 	{
 		if (errno == EINVAL || errno == EILSEQ)
 		{
@@ -1127,18 +1174,27 @@ BUILT_IN_COMMAND(encoding)
 					 recode_rules[x]->encoding);
 }
 
+#ifdef HAVE_NEWLOCALE
 static	locale_t	utf8_locale = 0;
+#endif
 
 void	create_utf8_locale (void)
 {
+#ifdef HAVE_NEWLOCALE
 	utf8_locale = newlocale(LC_ALL_MASK, "en_US.UTF-8", 0);
+#else
+	yell("*** Your system does not support newlocale(3), so case insensitive string comparison probably won't work for non-english languages.  Sorry.");
+#endif
 }
 
 int	mkupper_l (int codepoint)
 {
+#ifdef HAVE_NEWLOCALE
 	if (utf8_locale)
 		return towupper_l(codepoint, utf8_locale);
-	else if (codepoint >= 0x80)
+	else 
+#endif
+	     if (codepoint >= 0x80)
 		return codepoint;
 	else
 		return toupper(codepoint);
@@ -1147,9 +1203,12 @@ int	mkupper_l (int codepoint)
 
 int	mklower_l (int codepoint)
 {
+#ifdef HAVE_NEWLOCALE
 	if (utf8_locale)
 		return towlower_l(codepoint, utf8_locale);
-	else if (codepoint >= 0x80)
+	else 
+#endif
+	      if (codepoint >= 0x80)
 		return codepoint;
 	else
 		return tolower(codepoint);
@@ -1170,7 +1229,8 @@ int	mklower_l (int codepoint)
 int	sanity_check_encoding (const char *encoding)
 {
 	iconv_t		ti;
-	unsigned char	c, *cstr;
+	unsigned char	c;
+	char		*cstr;
 	size_t		c_size;
 	char		utf8str[16], *x;
 	size_t		x_size;
@@ -1213,7 +1273,7 @@ int	sanity_check_encoding (const char *encoding)
 	for (i = 32; i < 255; i++)
 	{
 		c = (unsigned char)i;
-		cstr = &c;
+		cstr = (char *)&c;
 		c_size = 1;
 		x = utf8str;
 		x_size = sizeof(utf8str);
