@@ -1,4 +1,4 @@
-/* $EPIC: reg.c,v 1.7 2004/01/29 02:20:26 jnelson Exp $ */
+/* $EPIC: reg.c,v 1.20 2012/11/26 05:09:35 jnelson Exp $ */
 /*
  * reg.c - "glob"-like wildcard pattern matching (not regexes)
  *
@@ -53,6 +53,7 @@
 #include "irc.h"
 #include "ircaux.h"
 #include "output.h"
+#include "reg.h"
 
 static	int	total_explicit;
 
@@ -93,7 +94,7 @@ static int	old_match(const char *pattern, const char *string)
 		{
 			if (old_match(pattern, string))
 				return 1;
-			else if (type == '*' || *string != ' ')
+			else if (type == '*' || !isspace(*string))
 				string++;
 			else
 				break;
@@ -124,13 +125,13 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 	int		sanity = 0;
 
 	if (x_debug & DEBUG_REGEX_DEBUG)
-		yell("Matching [%s] against [%s]", pattern, string);
+		privileged_yell("Matching [%s] against [%s]", pattern, string);
 
 	for (;;)
 	{
 		if (sanity++ > 100000)
 		{
-			yell("Infinite loop in match!");
+			privileged_yell("Infinite loop in match! -- Returning [0]");
 			return 0;
 		}
 
@@ -159,38 +160,32 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (!*string)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("More pattern, no source, Failure");
+					privileged_yell("More pattern, no source, Failure.  Returning [0]");
 				return 0;
 			}
 
-			/*
-			 * A backslash after a * sits there until we find
-		 	 * a char to match the character after it.  Then we
-			 * release the \, and the next iteration it will 
-			 * pass the following test...
-			 */
 			if (*pattern == '\\')
 			{
-			   if (x_debug & DEBUG_REGEX_DEBUG)
-			      yell("Trying to match [%d] after the backslash "
+                          if (x_debug & DEBUG_REGEX_DEBUG)
+                             privileged_yell("Trying to match [%d] after the backslash "
                                    "against [%d]", (int)*(pattern + 1), 
-						   (int)*string);
+                                                  (int)*string);
 
-			   if (tolower(*string) == tolower(*(pattern+1)))
-			   {
-			        if (x_debug & DEBUG_REGEX_DEBUG)
-			           yell("It matches!  Releasing the backslash");
+                          if (tolower(*string) == tolower(*(pattern+1)))
+                          {
+                               if (x_debug & DEBUG_REGEX_DEBUG)
+                                  privileged_yell("It matches!  Releasing the backslash");
 
-				pattern++;
-				asterisk = 0;
-				last_asterisk_point = string;
-				last_asterisk_count = count;
+                               pattern++;
+                               asterisk = 0;
+                               last_asterisk_point = string;
+                               last_asterisk_count = count;
 
-				pattern++;
-				string++;
-			   }
-			   else
-				string++;		/* Not this char */
+                               pattern++;
+                               string++;
+                          }
+                          else
+                               string++;               /* Not this char */
 			}
 
 			/*
@@ -208,7 +203,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 				(tolower(*string) == tolower(*pattern)))
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Found a [%d] in the source", *pattern);
+					privileged_yell("Found a [%d] in the source", *pattern);
 
 				asterisk = 0;
 				last_asterisk_point = string;
@@ -242,53 +237,50 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 				if (*pattern)
 				{
 					if (x_debug & DEBUG_REGEX_DEBUG)
-						yell("Ran out of source matching after %%");
+						privileged_yell("Ran out of source matching after %%.  Returning [0]");
 					return 0;
 				}
 				else
 				{
 					if (x_debug & DEBUG_REGEX_DEBUG)
-						yell("Success!");
+						privileged_yell("Success!  Returning [%d]", count);
 					return count;
 				}
 			}
 
 			/*
-			 * A backslash after a % sits there until we find
-		 	 * a char to match the character after it.  Then we
-			 * release the \, and the next iteration it will 
-			 * pass the following test...
+			 * XXXX Skip over any backslashes...
 			 */
 			if (*pattern == '\\')
 			{
-			   if (x_debug & DEBUG_REGEX_DEBUG)
-			      yell("Trying to match [%d] after the backslash "
+                          if (x_debug & DEBUG_REGEX_DEBUG)
+                             privileged_yell("Trying to match [%d] after the backslash "
                                    "against [%d]", (int)*(pattern + 1), 
-						   (int)*string);
+                                                  (int)*string);
 
-			   if (tolower(*string) == tolower(*(pattern+1)))
-			   {
-			        if (x_debug & DEBUG_REGEX_DEBUG)
-			           yell("It matches!  Releasing the backslash");
+                          if (tolower(*string) == tolower(*(pattern+1)))
+                          {
+                               if (x_debug & DEBUG_REGEX_DEBUG)
+                                  privileged_yell("It matches!  Releasing the backslash");
 
-				pattern++;
-				asterisk = 0;
-				last_asterisk_point = string;
-				last_asterisk_count = count;
+                               pattern++;
+                               percent = 0;
+                               last_percent_point = string;
+                               last_percent_count = count;
 
-				pattern++;
-				string++;
-			   }
-			   else if (*string == ' ')
-			   {
-				if (x_debug & DEBUG_REGEX_DEBUG)
-				{
-				   yell("Found a space trying to match the [%d] after a %%\\, so this doesn't match.", (int)*(pattern + 1));
-				   return 0;
-				}
-			   }
-			   else
-				string++;		/* Not this char */
+                               pattern++;
+                               string++;
+                          }
+                          else if (isspace(*string))
+                          {
+                               if (x_debug & DEBUG_REGEX_DEBUG)
+                               {
+                                  privileged_yell("Found a space trying to match the [%d] after a %%\\, so this doesn't match.  Returning [0]", (int)*(pattern + 1));
+                                  return 0;
+                               }
+                          }
+                          else
+                               string++;               /* Not this char */
 			}
 
 			/*
@@ -297,10 +289,10 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			 * go back to normal parsing mode, presumably with
 			 * the space after the %.
 			 */
-			if (*string == ' ')
+			else if (isspace(*string))
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Found a space");
+					privileged_yell("Found a space");
 				percent = 0;
 				last_percent_point = NULL;
 			}
@@ -318,7 +310,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			else
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Found a [%d]", *pattern);
+					privileged_yell("Found a [%d]", *pattern);
 
 				percent = 0;
 				last_percent_point = string;
@@ -374,7 +366,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (asterisk && !*pattern)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Wildcard at end of pattern. success!");
+					privileged_yell("Wildcard at end of pattern. success!  Returning [%d]", count);
 				return count;
 			}
 
@@ -396,7 +388,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (!*string)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Ran out of source matching ?");
+					privileged_yell("Ran out of source matching ?. Returning [0]");
 				return 0;
 			}
 			string++;
@@ -416,12 +408,12 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (!*pattern)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Lone \\ at end of pattern, failed");
+					privileged_yell("Lone \\ at end of pattern, failed.  Returning [0]");
 				return 0;
 			}
 
 			if (x_debug & DEBUG_REGEX_DEBUG)
-				yell("Comparing dequoted [%d] with [%d]",
+				privileged_yell("Comparing dequoted [%d] with [%d]",
 					*pattern, *string);
 
 			/*
@@ -431,12 +423,12 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (tolower(*pattern) != tolower(*string))
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("characters [%d] and [%d] after \\ dont match", tolower(*pattern), tolower(*string));
+					privileged_yell("characters [%d] and [%d] after \\ dont match.  Returning [0]", tolower(*pattern), tolower(*string));
 				return 0;
 			}
 
 			if (x_debug & DEBUG_REGEX_DEBUG)
-				yell("Apparantly they match");
+				privileged_yell("Apparantly they match");
 
 			count++, string++, pattern++;
 			break;
@@ -452,7 +444,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (!*pattern && !*string)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Success!");
+					privileged_yell("Success!  Returning [%d]", count);
 				return count;
 			}
 
@@ -464,7 +456,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			if (tolower(*pattern) == tolower(*string))
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("characters match");
+					privileged_yell("characters match");
 
 				count++, pattern++, string++;
 			}
@@ -479,7 +471,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			else if (last_asterisk_point)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("last_asterisk_point");
+					privileged_yell("last_asterisk_point");
 
                                 asterisk = 1;
                                 string = last_asterisk_point + 1;
@@ -489,7 +481,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			else if (last_percent_point)
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("last_percent_point");
+					privileged_yell("last_percent_point");
 
                                 percent = 1;
                                 string = last_percent_point + 1;
@@ -499,7 +491,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 			else
 			{
 				if (x_debug & DEBUG_REGEX_DEBUG)
-					yell("Characters [%d] and [%d] dont match", tolower(*pattern), tolower(*string));
+					privileged_yell("Characters [%d] and [%d] dont match.  Returning [0]", tolower(*pattern), tolower(*string));
 				return 0;
 			}
 
@@ -510,7 +502,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
 
 	/* NOTREACHED */
 	if (x_debug & DEBUG_REGEX_DEBUG)
-		yell("ABAONDON SHIP!");
+		privileged_yell("ABAONDON SHIP!  Returning [0]");
 	return 0;
 }
 
@@ -520,7 +512,7 @@ static int new_match (const unsigned char *pattern, const unsigned char *string)
  * In all cases where the string is matched by the pattern, then the "value"
  * of the match is 1 plus the number of non-wildcard characters in "str".
  *
- * \\[ and \\] handling done by Jeremy Nelson
+ * \\[ and \\] handling is an epic extension.
  */
 int wild_match (const char *p, const char *str)
 {
@@ -680,15 +672,26 @@ char *	pattern2regex (const char *pattern, int *weight)
 	const char *	pat;
 	size_t	retsize;
 
-	retsize = strlen(pattern) * 11 + 2;	/* big enough? */
+	*weight = 0;
+
+	retsize = strlen(pattern) * 11 + 4;	/* big enough? */
 	retval = new_malloc(retsize);
 	*retval = 0;
-	*weight = 0;
+	strlcat(retval, "^", retsize);
 
 	for (pat = pattern; *pat; pat++)
 	{
 	    switch (*pat)
 	    {
+		case '.' :
+		case '{' : case '}' :
+		case '(' : case ')' :
+		case '[' : case ']' :
+		case '^' : case '$' :
+		case '|' : case '+' :
+			strextend(retval, '\\', 1);
+			strextend(retval, *pat, 1);
+			break;
 		case '?' :
 			strextend(retval, '.', 1);
 			break;
@@ -702,10 +705,9 @@ char *	pattern2regex (const char *pattern, int *weight)
 			if (pat[1] != '[')
 				goto end;
 		{
-			char *patc, *ptr, *ptr2, *arg, *placeholder;
+			char *ptr, *ptr2, *arg, *placeholder;
 			int nest = 1;
 
-			patc = LOCAL_COPY(pat);
 			placeholder = ptr = ptr2 = strstr(pattern, "\\[");
 			do
 			{
@@ -730,7 +732,7 @@ char *	pattern2regex (const char *pattern, int *weight)
 				goto end;
 
 			*ptr = 0;
-			ptr += 2;
+			/* ptr += 2; */
 			*placeholder = 0;
 			placeholder += 2;
 
@@ -757,10 +759,12 @@ char *	pattern2regex (const char *pattern, int *weight)
 			break;
 	    }
 	}
+	strlcat(retval, "$", retsize);
 
-#if 0
-	yell("[%s] -> [%s]", pattern, retval);
-#endif
+	(*weight)++;		/* The nul counts towards the weight */
+
+	if (x_debug & DEBUG_REGEX_DEBUG)
+		privileged_yell("[%s] -> [%s]", pattern, retval);
 	return retval;
 }
 
