@@ -1,4 +1,4 @@
-/* $EPIC: vars.c,v 1.116 2014/04/09 17:51:08 jnelson Exp $ */
+/* $EPIC: vars.c,v 1.122 2015/05/16 22:36:47 jnelson Exp $ */
 /*
  * vars.c: All the dealing of the irc variables are handled here. 
  *
@@ -54,13 +54,13 @@
 #include "stack.h"
 #include "dcc.h"
 #include "keys.h"
-#include "translat.h"
 #include "timer.h"
 #include "clock.h"
 #include "mail.h"
 #include "reg.h"
 #include "commands.h"
 #include "ifcmd.h"
+#include "ssl.h"
 
 /*
  * The VIF_* macros stand for "(V)ariable.(i)nt_(f)lags", and have been
@@ -301,7 +301,6 @@ void 	init_variables_stage1 (void)
 #define DEFAULT_DEFAULT_REALNAME NULL
 	VAR(DEFAULT_REALNAME, 		STR,  NULL);
 #define DEFAULT_DEFAULT_USERNAME NULL
-	VAR(DEFAULT_SCRIPT_ENCODING,	STR,  NULL);
 	VAR(DEFAULT_USERNAME, 		STR,  NULL);
 	VAR(DISPATCH_UNKNOWN_COMMANDS,	BOOL, NULL);
 	VAR(DISPLAY, 			BOOL, NULL);
@@ -316,7 +315,6 @@ void 	init_variables_stage1 (void)
 	VAR(FLOOD_USERS,		INT,  NULL);
 	VAR(FLOOD_WARNING,		BOOL, NULL);
 	VAR(HIDE_PRIVATE_CHANNELS,	BOOL, update_all_status_wrapper);
-	VAR(HIGH_BIT_ESCAPE,		INT,  set_meta_8bit);
 	VAR(HOLD_SLIDER,		INT,  NULL);
 	VAR(INDENT,			BOOL, set_indent);
         VAR(INPUT_INDICATOR_LEFT,	STR, NULL);
@@ -373,6 +371,7 @@ void 	init_variables_stage1 (void)
 	VAR(SHOW_CHANNEL_NAMES, BOOL, NULL);
 	VAR(SHOW_NUMERICS, BOOL, NULL);
 	VAR(SHOW_STATUS_ALL, BOOL, update_all_status_wrapper);
+	VAR(SSL_ROOT_CERTS_LOCATION, STR, set_ssl_root_certs_location);
 	VAR(STATUS_AWAY, STR,  build_status);
 	VAR(STATUS_CHANNEL, STR,  build_status);
 	VAR(STATUS_CHANOP, STR,  build_status);
@@ -447,10 +446,7 @@ void 	init_variables_stage1 (void)
 	VAR(SUPPRESS_FROM_REMOTE_SERVER, BOOL, NULL);
 	VAR(SWITCH_CHANNELS_BETWEEN_WINDOWS, BOOL, NULL);
 	VAR(TERM_DOES_BRIGHT_BLINK, BOOL, NULL);
-#define DEFAULT_TRANSLATION NULL
-	VAR(TRANSLATION, STR,  set_translation);
-#define DEFAULT_TRANSLATION_PATH NULL
-	VAR(TRANSLATION_PATH, STR,  NULL);
+	VAR(TMUX_OPTIONS, STR,  NULL);
 	VAR(USER_INFORMATION, STR, NULL);
 	VAR(WORD_BREAK, STR,  NULL);
 #define DEFAULT_WSERV_PATH WSERV_PATH
@@ -581,7 +577,7 @@ int 	set_variable (const char *name, IrcVariable *var, const char *orig_value, i
 			break;
 		}
 
-		if ((codepoint = next_code_point((const unsigned char **)&value)) == -1)
+		if ((codepoint = next_code_point((const unsigned char **)&value, 0)) == -1)
 		{
 			say("New value of %s could not be determined", name);
 			retval = -1;
@@ -1090,8 +1086,10 @@ static void    set_wserv_type (void *stuff)
 		return;		/* It's ok */
 	if (!my_stricmp(s, "XTERM"))
 		return;		/* It's ok */
+	if (!my_stricmp(s, "TMUX"))
+		return;		/* It's ok */
 
-	say("SET WSERV_TYPE must be either SCREEN or XTERM");
+	say("SET WSERV_TYPE must be either SCREEN, XTERM or TMUX");
 	new_free(&v->string);
 }
 
@@ -1214,6 +1212,7 @@ void	do_stack_set (int type, char *args)
 }
 #endif
 
+#if 0
 void    help_topics_set (FILE *f)
 {                                                                               
         int     i;
@@ -1221,5 +1220,5 @@ void    help_topics_set (FILE *f)
 	for (i = 0; i < var_bucket->numitems; i++)
                 fprintf(f, "set %s\n", var_bucket->list[i].name);
 }
-
+#endif
 
