@@ -64,6 +64,8 @@
  */
 
 #include "irc.h"
+#include "ircaux.h"
+#include "output.h"
 
 struct interval {
   int first;
@@ -213,24 +215,22 @@ int	codepoint_numcolumns (int ucs)
 }
 
 
-int     next_code_point (const unsigned char **i)
+int     next_code_point (const unsigned char **i, int resync)
 {
         int     offset;
         unsigned char    a, b, c, d;
         const unsigned char *str;
-        int     result = -1;
-static	const unsigned char *sanity = NULL;
-
-	if (*i == sanity)
-	{
-		yell("XXX####XXX NEXT_CODE_POINT LOOP XXX####XXX");
-		yell("The previous call to next_code_point failed and it was immediately called again with the same (broken) string.  This will result in an infinite loop.  I'm returning 0 hoping to stop this.");
-		return 0;
-	}
+        int     result;
 
+	if (!i || !*i)
+		return 0;	/* What is this? */
 
+    /* Keep skipping bytes until we find one that works */
+    for (; (**i); (*i)++)
+    {
         str = *i;
         a = b = c = d = 0;
+	result = -1;
 
 	/* Forcibly refuse to walk past the nul */
 	if (!str[0])
@@ -279,11 +279,7 @@ static	const unsigned char *sanity = NULL;
 				(c & 0x3f);
                     (*i) += 3;
                   }
-		  else
-			/*yell("3 bytes - byte 3 was bad %X", (int)c)*/;
 		}
-		else
-			/*yell("3 bytes - byte 2 was bad %X", (int)b)*/;
         }
 
         /* The 4 high bits are set only?  -- 4 bytes*/
@@ -305,23 +301,19 @@ static	const unsigned char *sanity = NULL;
 		}
         }
 
-	else if ((a & 0x80) == 0x80)
-	{
-		/*yell("? bytes: byte 1 was bad: %X", (int)a);*/
-	}
-
 	/* If result is -1, something is wrong */
 	if (result == -1)
 	{
-		sanity = *i;
-/*
-		yell("next_code_point: result == -1 for [%s] [%d] [%d] [%d] [%d]", (*i), (int)a, (int)b, (int)c, (int)d);
-*/
+		if (resync)
+			continue;
 	}
-	else
-		sanity = NULL;
 
         return result;
+
+    }
+
+    /* If we hit the end of the string, return nul */
+    return 0;
 }
 
 /*
@@ -442,16 +434,14 @@ int     partial_code_point (const unsigned char *i)
 			return -1;
         }
 
-	else
-		return -1;
-
+	return -1;
 }
 
 
 int	grab_codepoint (const unsigned char *x)
 {
 	const unsigned char *str = x;
-	return next_code_point(&str);
+	return next_code_point(&str, 1);
 }
 
 /*
@@ -480,7 +470,7 @@ int	quick_display_column_count (const unsigned char *str)
 	int	x;
 
 	s = str;
-	while ((code_point = next_code_point(&s)))
+	while ((code_point = next_code_point(&s, 1)))
 	{
 		if ((x = codepoint_numcolumns(code_point)) == -1)
 			x = 0;
@@ -498,7 +488,7 @@ int	input_column_count (const unsigned char *str)
 	int	x;
 
 	s = str;
-	while ((code_point = next_code_point(&s)))
+	while ((code_point = next_code_point(&s, 1)))
 	{
 		if ((x = codepoint_numcolumns(code_point)) == -1)
 			x = 1;
@@ -562,7 +552,7 @@ int     previous_code_point (const unsigned char *st, const unsigned char **i)
 		c--;
 
 	*i = c;
-	return next_code_point(&c);
+	return next_code_point(&c, 1);
 }
 
 
